@@ -2,11 +2,11 @@
 #######################################################################
 """Interfaces for the Zope 3 based ng.content.article package
 
-$Id: interfaces.py 51577 2008-08-31 12:16:31Z cray $
+$Id: interfaces.py 51881 2008-10-20 19:05:41Z cray $
 """
 __author__  = "Andrey Orlov, 2007"
 __license__ = "GPL"
-__version__ = "$Revision: 51577 $"
+__version__ = "$Revision: 51881 $"
  
 from zope.interface import Interface,invariant,Invalid
 from zope.schema import Text, TextLine, Field, Bool, URI, Datetime, Object
@@ -17,6 +17,7 @@ from ks.page.idocumentlogo.interfaces import IDocumentLogo
 from zope.app.container.interfaces import IReadContainer
 from ng.schema.regexp.regexpfield import Regexp
 import datetime
+import pytz
 from ng.schema.interfaceswitcher.interfacechoicefield import InterfaceChoice
 from ng.lib.dynamicdefault import DynamicDefault
 
@@ -55,7 +56,7 @@ class IDocAbstract(Interface) :
                                   
     created = DynamicDefault(Datetime,title = u'Date/Time',
         description = u'Date/Time',
-        default = datetime.datetime.today,
+        default = lambda : datetime.datetime.now(pytz.utc),
         required = True)
    
     author = TextLine(title = u'Author',
